@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class CarePlan(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -317,6 +317,43 @@ class CarePlan(domainresource.DomainResource):
         None, alias="_title", title="Extension field for ``title``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CarePlan`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "definition",
+            "basedOn",
+            "replaces",
+            "partOf",
+            "status",
+            "intent",
+            "category",
+            "title",
+            "description",
+            "subject",
+            "context",
+            "period",
+            "author",
+            "careTeam",
+            "addresses",
+            "supportingInfo",
+            "goal",
+            "activity",
+            "note",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_951(
         cls, values: typing.Dict[str, typing.Any]
@@ -378,7 +415,7 @@ class CarePlan(domainresource.DomainResource):
 
 
 class CarePlanActivity(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -467,9 +504,26 @@ class CarePlanActivity(backboneelement.BackboneElement):
         ],
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CarePlanActivity`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "outcomeCodeableConcept",
+            "outcomeReference",
+            "progress",
+            "reference",
+            "detail",
+        ]
+
 
 class CarePlanActivityDetail(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -767,6 +821,38 @@ class CarePlanActivityDetail(backboneelement.BackboneElement):
         None, alias="_statusReason", title="Extension field for ``statusReason``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CarePlanActivityDetail`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "category",
+            "definition",
+            "code",
+            "reasonCode",
+            "reasonReference",
+            "goal",
+            "status",
+            "statusReason",
+            "prohibited",
+            "scheduledTiming",
+            "scheduledPeriod",
+            "scheduledString",
+            "location",
+            "performer",
+            "productCodeableConcept",
+            "productReference",
+            "productReference",
+            "dailyAmount",
+            "quantity",
+            "description",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2389(
         cls, values: typing.Dict[str, typing.Any]
