@@ -14,7 +14,7 @@ from . import element, fhirtypes
 
 
 class HumanName(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -129,3 +129,21 @@ class HumanName(element.Element):
     use__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_use", title="Extension field for ``use``."
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``HumanName`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "use",
+            "text",
+            "family",
+            "given",
+            "prefix",
+            "suffix",
+            "period",
+        ]
