@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class SearchParameter(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -434,6 +434,47 @@ class SearchParameter(domainresource.DomainResource):
         None, alias="_xpathUsage", title="Extension field for ``xpathUsage``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``SearchParameter`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "url",
+            "version",
+            "name",
+            "status",
+            "experimental",
+            "date",
+            "publisher",
+            "contact",
+            "useContext",
+            "jurisdiction",
+            "purpose",
+            "code",
+            "base",
+            "type",
+            "derivedFrom",
+            "description",
+            "expression",
+            "xpath",
+            "xpathUsage",
+            "target",
+            "comparator",
+            "modifier",
+            "chain",
+            "component",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1724(
         cls, values: typing.Dict[str, typing.Any]
@@ -503,7 +544,7 @@ class SearchParameter(domainresource.DomainResource):
 
 
 class SearchParameterComponent(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -540,6 +581,14 @@ class SearchParameterComponent(backboneelement.BackboneElement):
         None, alias="_expression", title="Extension field for ``expression``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``SearchParameterComponent`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "definition", "expression"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2673(
         cls, values: typing.Dict[str, typing.Any]
