@@ -16,7 +16,7 @@ from . import element, fhirtypes
 
 
 class Signature(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -170,6 +170,33 @@ class Signature(element.Element):
         None, alias="_whoUri", title="Extension field for ``whoUri``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Signature`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "type",
+            "when",
+            "whoUri",
+            "whoReference",
+            "whoReference",
+            "whoReference",
+            "whoReference",
+            "whoReference",
+            "onBehalfOfUri",
+            "onBehalfOfReference",
+            "onBehalfOfReference",
+            "onBehalfOfReference",
+            "onBehalfOfReference",
+            "onBehalfOfReference",
+            "contentType",
+            "blob",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1130(
         cls, values: typing.Dict[str, typing.Any]
