@@ -16,7 +16,7 @@ from . import domainresource, fhirtypes
 
 
 class AppointmentResponse(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -149,6 +149,31 @@ class AppointmentResponse(domainresource.DomainResource):
         None, alias="_start", title="Extension field for ``start``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``AppointmentResponse`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "appointment",
+            "start",
+            "end",
+            "participantType",
+            "actor",
+            "participantStatus",
+            "comment",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2180(
         cls, values: typing.Dict[str, typing.Any]
