@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Composition(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -243,6 +243,38 @@ class Composition(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Composition`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "type",
+            "category",
+            "subject",
+            "encounter",
+            "date",
+            "author",
+            "title",
+            "confidentiality",
+            "attester",
+            "custodian",
+            "relatesTo",
+            "event",
+            "section",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1349(
         cls, values: typing.Dict[str, typing.Any]
@@ -308,7 +340,7 @@ class Composition(domainresource.DomainResource):
 
 
 class CompositionAttester(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -363,6 +395,14 @@ class CompositionAttester(backboneelement.BackboneElement):
         None, alias="_time", title="Extension field for ``time``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CompositionAttester`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "mode", "time", "party"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2197(
         cls, values: typing.Dict[str, typing.Any]
@@ -424,7 +464,7 @@ class CompositionAttester(backboneelement.BackboneElement):
 
 
 class CompositionEvent(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -478,9 +518,17 @@ class CompositionEvent(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CompositionEvent`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "code", "period", "detail"]
+
 
 class CompositionRelatesTo(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -536,6 +584,21 @@ class CompositionRelatesTo(backboneelement.BackboneElement):
         enum_reference_types=["Composition"],
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CompositionRelatesTo`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "code",
+            "targetIdentifier",
+            "targetReference",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2265(
         cls, values: typing.Dict[str, typing.Any]
@@ -635,7 +698,7 @@ class CompositionRelatesTo(backboneelement.BackboneElement):
 
 
 class CompositionSection(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -797,3 +860,25 @@ class CompositionSection(backboneelement.BackboneElement):
     title__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_title", title="Extension field for ``title``."
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``CompositionSection`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "title",
+            "code",
+            "author",
+            "focus",
+            "text",
+            "mode",
+            "orderedBy",
+            "entry",
+            "emptyReason",
+            "section",
+        ]
