@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class DiagnosticReport(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -312,6 +312,42 @@ class DiagnosticReport(domainresource.DomainResource):
         enum_reference_types=["Patient", "Group", "Device", "Location"],
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``DiagnosticReport`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "basedOn",
+            "status",
+            "category",
+            "code",
+            "subject",
+            "encounter",
+            "effectiveDateTime",
+            "effectivePeriod",
+            "issued",
+            "performer",
+            "resultsInterpreter",
+            "specimen",
+            "result",
+            "imagingStudy",
+            "media",
+            "conclusion",
+            "conclusionCode",
+            "presentedForm",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1849(
         cls, values: typing.Dict[str, typing.Any]
@@ -411,7 +447,7 @@ class DiagnosticReport(domainresource.DomainResource):
 
 
 class DiagnosticReportMedia(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -449,3 +485,11 @@ class DiagnosticReportMedia(backboneelement.BackboneElement):
         # note: Listed Resource Type(s) should be allowed as Reference.
         enum_reference_types=["Media"],
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``DiagnosticReportMedia`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "comment", "link"]
