@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class EpisodeOfCare(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -199,6 +199,35 @@ class EpisodeOfCare(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``EpisodeOfCare`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "statusHistory",
+            "type",
+            "diagnosis",
+            "patient",
+            "managingOrganization",
+            "period",
+            "referralRequest",
+            "careManager",
+            "team",
+            "account",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1443(
         cls, values: typing.Dict[str, typing.Any]
@@ -260,7 +289,7 @@ class EpisodeOfCare(domainresource.DomainResource):
 
 
 class EpisodeOfCareDiagnosis(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -307,9 +336,17 @@ class EpisodeOfCareDiagnosis(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``EpisodeOfCareDiagnosis`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "condition", "role", "rank"]
+
 
 class EpisodeOfCareStatusHistory(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -357,6 +394,14 @@ class EpisodeOfCareStatusHistory(backboneelement.BackboneElement):
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``EpisodeOfCareStatusHistory`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "status", "period"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2861(
         cls, values: typing.Dict[str, typing.Any]
