@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class EvidenceVariable(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -428,6 +428,50 @@ class EvidenceVariable(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``EvidenceVariable`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "url",
+            "identifier",
+            "version",
+            "name",
+            "title",
+            "shortTitle",
+            "subtitle",
+            "status",
+            "date",
+            "publisher",
+            "contact",
+            "description",
+            "note",
+            "useContext",
+            "jurisdiction",
+            "copyright",
+            "approvalDate",
+            "lastReviewDate",
+            "effectivePeriod",
+            "topic",
+            "author",
+            "editor",
+            "reviewer",
+            "endorser",
+            "relatedArtifact",
+            "type",
+            "characteristic",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1779(
         cls, values: typing.Dict[str, typing.Any]
@@ -489,7 +533,7 @@ class EvidenceVariable(domainresource.DomainResource):
 
 
 class EvidenceVariableCharacteristic(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -743,6 +787,33 @@ class EvidenceVariableCharacteristic(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``EvidenceVariableCharacteristic`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "description",
+            "definitionReference",
+            "definitionCanonical",
+            "definitionCodeableConcept",
+            "definitionExpression",
+            "definitionDataRequirement",
+            "definitionTriggerDefinition",
+            "usageContext",
+            "exclude",
+            "participantEffectiveDateTime",
+            "participantEffectivePeriod",
+            "participantEffectiveDuration",
+            "participantEffectiveTiming",
+            "timeFromStart",
+            "groupMeasure",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_3226(
         cls, values: typing.Dict[str, typing.Any]
