@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Goal(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -266,6 +266,40 @@ class Goal(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Goal`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "lifecycleStatus",
+            "achievementStatus",
+            "category",
+            "priority",
+            "description",
+            "subject",
+            "startDate",
+            "startCodeableConcept",
+            "target",
+            "statusDate",
+            "statusReason",
+            "expressedBy",
+            "addresses",
+            "note",
+            "outcomeCode",
+            "outcomeReference",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_566(
         cls, values: typing.Dict[str, typing.Any]
@@ -365,7 +399,7 @@ class Goal(domainresource.DomainResource):
 
 
 class GoalTarget(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -569,6 +603,28 @@ class GoalTarget(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``GoalTarget`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "measure",
+            "detailQuantity",
+            "detailRange",
+            "detailCodeableConcept",
+            "detailString",
+            "detailBoolean",
+            "detailInteger",
+            "detailRatio",
+            "dueDate",
+            "dueDuration",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_1189(
         cls, values: typing.Dict[str, typing.Any]
