@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class ImagingStudy(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -308,6 +308,43 @@ class ImagingStudy(domainresource.DomainResource):
         enum_reference_types=["Patient", "Device", "Group"],
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImagingStudy`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "modality",
+            "subject",
+            "encounter",
+            "started",
+            "basedOn",
+            "referrer",
+            "interpreter",
+            "endpoint",
+            "numberOfSeries",
+            "numberOfInstances",
+            "procedureReference",
+            "procedureCode",
+            "location",
+            "reasonCode",
+            "reasonReference",
+            "note",
+            "description",
+            "series",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1431(
         cls, values: typing.Dict[str, typing.Any]
@@ -369,7 +406,7 @@ class ImagingStudy(domainresource.DomainResource):
 
 
 class ImagingStudySeries(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -533,6 +570,30 @@ class ImagingStudySeries(backboneelement.BackboneElement):
         None, alias="_uid", title="Extension field for ``uid``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImagingStudySeries`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "uid",
+            "number",
+            "modality",
+            "description",
+            "numberOfInstances",
+            "endpoint",
+            "bodySite",
+            "laterality",
+            "specimen",
+            "started",
+            "performer",
+            "instance",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2044(
         cls, values: typing.Dict[str, typing.Any]
@@ -594,7 +655,7 @@ class ImagingStudySeries(backboneelement.BackboneElement):
 
 
 class ImagingStudySeriesInstance(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -651,6 +712,22 @@ class ImagingStudySeriesInstance(backboneelement.BackboneElement):
         None, alias="_uid", title="Extension field for ``uid``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImagingStudySeriesInstance`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "uid",
+            "sopClass",
+            "number",
+            "title",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2851(
         cls, values: typing.Dict[str, typing.Any]
@@ -712,7 +789,7 @@ class ImagingStudySeriesInstance(backboneelement.BackboneElement):
 
 
 class ImagingStudySeriesPerformer(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -749,3 +826,11 @@ class ImagingStudySeriesPerformer(backboneelement.BackboneElement):
         # if property is element of this resource.
         element_property=True,
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImagingStudySeriesPerformer`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "function", "actor"]
