@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class Immunization(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -376,6 +376,52 @@ class Immunization(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Immunization`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "statusReason",
+            "vaccineCode",
+            "patient",
+            "encounter",
+            "occurrenceDateTime",
+            "occurrenceString",
+            "recorded",
+            "primarySource",
+            "reportOrigin",
+            "location",
+            "manufacturer",
+            "lotNumber",
+            "expirationDate",
+            "site",
+            "route",
+            "doseQuantity",
+            "performer",
+            "note",
+            "reasonCode",
+            "reasonReference",
+            "isSubpotent",
+            "subpotentReason",
+            "education",
+            "programEligibility",
+            "fundingSource",
+            "reaction",
+            "protocolApplied",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1467(
         cls, values: typing.Dict[str, typing.Any]
@@ -475,7 +521,7 @@ class Immunization(domainresource.DomainResource):
 
 
 class ImmunizationEducation(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -539,9 +585,25 @@ class ImmunizationEducation(backboneelement.BackboneElement):
         None, alias="_reference", title="Extension field for ``reference``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImmunizationEducation`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "documentType",
+            "reference",
+            "publicationDate",
+            "presentationDate",
+        ]
+
 
 class ImmunizationPerformer(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -574,9 +636,17 @@ class ImmunizationPerformer(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImmunizationPerformer`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "function", "actor"]
+
 
 class ImmunizationProtocolApplied(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -695,6 +765,25 @@ class ImmunizationProtocolApplied(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImmunizationProtocolApplied`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "series",
+            "authority",
+            "targetDisease",
+            "doseNumberPositiveInt",
+            "doseNumberString",
+            "seriesDosesPositiveInt",
+            "seriesDosesString",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_3010(
         cls, values: typing.Dict[str, typing.Any]
@@ -738,7 +827,7 @@ class ImmunizationProtocolApplied(backboneelement.BackboneElement):
 
 
 class ImmunizationReaction(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -783,3 +872,11 @@ class ImmunizationReaction(backboneelement.BackboneElement):
     reported__ext: fhirtypes.FHIRPrimitiveExtensionType = Field(
         None, alias="_reported", title="Extension field for ``reported``."
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImmunizationReaction`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "date", "detail", "reported"]
