@@ -16,7 +16,7 @@ from . import domainresource, fhirtypes
 
 
 class ImmunizationEvaluation(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -232,6 +232,38 @@ class ImmunizationEvaluation(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImmunizationEvaluation`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "patient",
+            "date",
+            "authority",
+            "targetDisease",
+            "immunizationEvent",
+            "doseStatus",
+            "doseStatusReason",
+            "description",
+            "series",
+            "doseNumberPositiveInt",
+            "doseNumberString",
+            "seriesDosesPositiveInt",
+            "seriesDosesString",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2515(
         cls, values: typing.Dict[str, typing.Any]
