@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class ImmunizationRecommendation(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -82,6 +82,28 @@ class ImmunizationRecommendation(domainresource.DomainResource):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImmunizationRecommendation`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "patient",
+            "date",
+            "authority",
+            "recommendation",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2928(
         cls, values: typing.Dict[str, typing.Any]
@@ -143,7 +165,7 @@ class ImmunizationRecommendation(domainresource.DomainResource):
 
 
 class ImmunizationRecommendationRecommendation(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -347,6 +369,32 @@ class ImmunizationRecommendationRecommendation(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImmunizationRecommendationRecommendation`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "vaccineCode",
+            "targetDisease",
+            "contraindicatedVaccineCode",
+            "forecastStatus",
+            "forecastReason",
+            "dateCriterion",
+            "description",
+            "series",
+            "doseNumberPositiveInt",
+            "doseNumberString",
+            "seriesDosesPositiveInt",
+            "seriesDosesString",
+            "supportingImmunization",
+            "supportingPatientInformation",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_4389(
         cls, values: typing.Dict[str, typing.Any]
@@ -392,7 +440,7 @@ class ImmunizationRecommendationRecommendation(backboneelement.BackboneElement):
 class ImmunizationRecommendationRecommendationDateCriterion(
     backboneelement.BackboneElement
 ):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -430,6 +478,14 @@ class ImmunizationRecommendationRecommendationDateCriterion(
         None, alias="_value", title="Extension field for ``value``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``ImmunizationRecommendationRecommendationDateCriterion`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "code", "value"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_5714(
         cls, values: typing.Dict[str, typing.Any]
