@@ -14,7 +14,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class MedicinalProductContraindication(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -100,9 +100,33 @@ class MedicinalProductContraindication(domainresource.DomainResource):
         enum_reference_types=["MedicinalProductIndication"],
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MedicinalProductContraindication`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "subject",
+            "disease",
+            "diseaseStatus",
+            "comorbidity",
+            "therapeuticIndication",
+            "otherTherapy",
+            "population",
+        ]
+
 
 class MedicinalProductContraindicationOtherTherapy(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -163,6 +187,21 @@ class MedicinalProductContraindicationOtherTherapy(backboneelement.BackboneEleme
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MedicinalProductContraindicationOtherTherapy`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "therapyRelationshipType",
+            "medicationCodeableConcept",
+            "medicationReference",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_4757(
         cls, values: typing.Dict[str, typing.Any]
