@@ -14,7 +14,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class MedicinalProductIndication(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -117,9 +117,35 @@ class MedicinalProductIndication(domainresource.DomainResource):
         enum_reference_types=["MedicinalProductUndesirableEffect"],
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MedicinalProductIndication`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "subject",
+            "diseaseSymptomProcedure",
+            "diseaseStatus",
+            "comorbidity",
+            "intendedEffect",
+            "duration",
+            "otherTherapy",
+            "undesirableEffect",
+            "population",
+        ]
+
 
 class MedicinalProductIndicationOtherTherapy(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -180,6 +206,21 @@ class MedicinalProductIndicationOtherTherapy(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``MedicinalProductIndicationOtherTherapy`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "therapyRelationshipType",
+            "medicationCodeableConcept",
+            "medicationReference",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_one_of_many_4110(
         cls, values: typing.Dict[str, typing.Any]
