@@ -16,7 +16,7 @@ from . import domainresource, fhirtypes
 
 
 class PaymentNotice(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -167,6 +167,35 @@ class PaymentNotice(domainresource.DomainResource):
         None, alias="_status", title="Extension field for ``status``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``PaymentNotice`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "identifier",
+            "status",
+            "request",
+            "response",
+            "created",
+            "provider",
+            "payment",
+            "paymentDate",
+            "payee",
+            "recipient",
+            "amount",
+            "paymentStatus",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1525(
         cls, values: typing.Dict[str, typing.Any]
