@@ -12,7 +12,7 @@ from . import element, fhirtypes
 
 
 class Range(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -39,3 +39,11 @@ class Range(element.Element):
         # if property is element of this resource.
         element_property=True,
     )
+
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``Range`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "low", "high"]
