@@ -16,7 +16,7 @@ from . import backboneelement, domainresource, fhirtypes
 
 
 class TestScript(domainresource.DomainResource):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -375,6 +375,47 @@ class TestScript(domainresource.DomainResource):
         None, alias="_version", title="Extension field for ``version``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScript`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "meta",
+            "implicitRules",
+            "language",
+            "text",
+            "contained",
+            "extension",
+            "modifierExtension",
+            "url",
+            "identifier",
+            "version",
+            "name",
+            "title",
+            "status",
+            "experimental",
+            "date",
+            "publisher",
+            "contact",
+            "description",
+            "useContext",
+            "jurisdiction",
+            "purpose",
+            "copyright",
+            "origin",
+            "destination",
+            "metadata",
+            "fixture",
+            "profile",
+            "variable",
+            "setup",
+            "test",
+            "teardown",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1245(
         cls, values: typing.Dict[str, typing.Any]
@@ -440,7 +481,7 @@ class TestScript(domainresource.DomainResource):
 
 
 class TestScriptDestination(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -480,6 +521,14 @@ class TestScriptDestination(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScriptDestination`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "index", "profile"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2393(
         cls, values: typing.Dict[str, typing.Any]
@@ -541,7 +590,7 @@ class TestScriptDestination(backboneelement.BackboneElement):
 
 
 class TestScriptFixture(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -602,6 +651,21 @@ class TestScriptFixture(backboneelement.BackboneElement):
         enum_reference_types=["Resource"],
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScriptFixture`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "autocreate",
+            "autodelete",
+            "resource",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1973(
         cls, values: typing.Dict[str, typing.Any]
@@ -666,7 +730,7 @@ class TestScriptFixture(backboneelement.BackboneElement):
 
 
 class TestScriptMetadata(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -702,9 +766,17 @@ class TestScriptMetadata(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScriptMetadata`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "link", "capability"]
+
 
 class TestScriptMetadataCapability(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -821,6 +893,25 @@ class TestScriptMetadataCapability(backboneelement.BackboneElement):
         None, alias="_validated", title="Extension field for ``validated``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScriptMetadataCapability`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "required",
+            "validated",
+            "description",
+            "origin",
+            "destination",
+            "link",
+            "capabilities",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3077(
         cls, values: typing.Dict[str, typing.Any]
@@ -886,7 +977,7 @@ class TestScriptMetadataCapability(backboneelement.BackboneElement):
 
 
 class TestScriptMetadataLink(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -924,6 +1015,14 @@ class TestScriptMetadataLink(backboneelement.BackboneElement):
         None, alias="_url", title="Extension field for ``url``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScriptMetadataLink`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "url", "description"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2435(
         cls, values: typing.Dict[str, typing.Any]
@@ -985,7 +1084,7 @@ class TestScriptMetadataLink(backboneelement.BackboneElement):
 
 
 class TestScriptOrigin(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1021,6 +1120,14 @@ class TestScriptOrigin(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScriptOrigin`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "index", "profile"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1855(
         cls, values: typing.Dict[str, typing.Any]
@@ -1082,7 +1189,7 @@ class TestScriptOrigin(backboneelement.BackboneElement):
 
 
 class TestScriptSetup(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1100,9 +1207,17 @@ class TestScriptSetup(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScriptSetup`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "action"]
+
 
 class TestScriptSetupAction(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1133,9 +1248,17 @@ class TestScriptSetupAction(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScriptSetupAction`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "operation", "assert"]
+
 
 class TestScriptSetupActionAssert(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1506,6 +1629,40 @@ class TestScriptSetupActionAssert(backboneelement.BackboneElement):
         None, alias="_warningOnly", title="Extension field for ``warningOnly``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScriptSetupActionAssert`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "label",
+            "description",
+            "direction",
+            "compareToSourceId",
+            "compareToSourceExpression",
+            "compareToSourcePath",
+            "contentType",
+            "expression",
+            "headerField",
+            "minimumId",
+            "navigationLinks",
+            "operator",
+            "path",
+            "requestMethod",
+            "requestURL",
+            "resource",
+            "response",
+            "responseCode",
+            "sourceId",
+            "validateProfileId",
+            "value",
+            "warningOnly",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3006(
         cls, values: typing.Dict[str, typing.Any]
@@ -1567,7 +1724,7 @@ class TestScriptSetupActionAssert(backboneelement.BackboneElement):
 
 
 class TestScriptSetupActionOperation(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1811,6 +1968,35 @@ class TestScriptSetupActionOperation(backboneelement.BackboneElement):
         None, alias="_url", title="Extension field for ``url``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScriptSetupActionOperation`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "type",
+            "resource",
+            "label",
+            "description",
+            "accept",
+            "contentType",
+            "destination",
+            "encodeRequestUrl",
+            "method",
+            "origin",
+            "params",
+            "requestHeader",
+            "requestId",
+            "responseId",
+            "sourceId",
+            "targetId",
+            "url",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_3319(
         cls, values: typing.Dict[str, typing.Any]
@@ -1872,7 +2058,7 @@ class TestScriptSetupActionOperation(backboneelement.BackboneElement):
 
 
 class TestScriptSetupActionOperationRequestHeader(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1908,6 +2094,14 @@ class TestScriptSetupActionOperationRequestHeader(backboneelement.BackboneElemen
         None, alias="_value", title="Extension field for ``value``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScriptSetupActionOperationRequestHeader`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "field", "value"]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_4653(
         cls, values: typing.Dict[str, typing.Any]
@@ -1969,7 +2163,7 @@ class TestScriptSetupActionOperationRequestHeader(backboneelement.BackboneElemen
 
 
 class TestScriptTeardown(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -1989,9 +2183,17 @@ class TestScriptTeardown(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScriptTeardown`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "action"]
+
 
 class TestScriptTeardownAction(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -2010,9 +2212,17 @@ class TestScriptTeardownAction(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScriptTeardownAction`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "operation"]
+
 
 class TestScriptTest(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -2060,9 +2270,17 @@ class TestScriptTest(backboneelement.BackboneElement):
         None, alias="_name", title="Extension field for ``name``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScriptTest`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "name", "description", "action"]
+
 
 class TestScriptTestAction(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -2093,9 +2311,17 @@ class TestScriptTestAction(backboneelement.BackboneElement):
         element_property=True,
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScriptTestAction`` according specification,
+        with preserving original sequence order.
+        """
+        return ["id", "extension", "modifierExtension", "operation", "assert"]
+
 
 class TestScriptVariable(backboneelement.BackboneElement):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -2223,6 +2449,26 @@ class TestScriptVariable(backboneelement.BackboneElement):
         None, alias="_sourceId", title="Extension field for ``sourceId``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TestScriptVariable`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "modifierExtension",
+            "name",
+            "defaultValue",
+            "description",
+            "expression",
+            "headerField",
+            "hint",
+            "path",
+            "sourceId",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_2036(
         cls, values: typing.Dict[str, typing.Any]
