@@ -16,7 +16,7 @@ from . import element, fhirtypes
 
 
 class TriggerDefinition(element.Element):
-    """Disclaimer: Any field name ends with ``__ext`` does't part of
+    """Disclaimer: Any field name ends with ``__ext`` doesn't part of
     Resource StructureDefinition, instead used to enable Extensibility feature
     for FHIR Primitive Data Types.
 
@@ -153,6 +153,25 @@ class TriggerDefinition(element.Element):
         None, alias="_type", title="Extension field for ``type``."
     )
 
+    @classmethod
+    def elements_sequence(cls):
+        """returning all elements names from
+        ``TriggerDefinition`` according specification,
+        with preserving original sequence order.
+        """
+        return [
+            "id",
+            "extension",
+            "type",
+            "name",
+            "timingTiming",
+            "timingReference",
+            "timingDate",
+            "timingDateTime",
+            "data",
+            "condition",
+        ]
+
     @root_validator(pre=True, allow_reuse=True)
     def validate_required_primitive_elements_1951(
         cls, values: typing.Dict[str, typing.Any]
